@@ -1,21 +1,25 @@
 #!/usr/bin/env python
 
+from __future__ import annotations
+
 import base64
 import datetime
 import itertools
 import os
 import pathlib
+import platform
 import subprocess
 import sys
-from typing import Dict
 
 import pytest
 
-import libzim.writer
-from libzim.reader import Archive
-from libzim.search import Query, Searcher
-from libzim.suggestion import SuggestionSearcher
-from libzim.writer import (
+import libzim.writer  # pyright: ignore [reportMissingModuleSource]
+from libzim.reader import Archive  # pyright: ignore [reportMissingModuleSource]
+from libzim.search import Query, Searcher  # pyright: ignore [reportMissingModuleSource]
+from libzim.suggestion import (  # pyright: ignore [reportMissingModuleSource]
+    SuggestionSearcher,
+)
+from libzim.writer import (  # pyright: ignore [reportMissingModuleSource]
     Blob,
     ContentProvider,
     Creator,
@@ -46,10 +50,10 @@ class StaticItem(libzim.writer.Item):
 
     def get_contentprovider(self) -> libzim.writer.ContentProvider:
         if getattr(self, "filepath", None):
-            return FileProvider(filepath=self.filepath)
+            return FileProvider(filepath=getattr(self, "filepath", ""))
         return StringProvider(content=getattr(self, "content", ""))
 
-    def get_hints(self) -> Dict[Hint, int]:
+    def get_hints(self) -> dict[Hint, int]:
         return getattr(self, "hints", {Hint.FRONT_ARTICLE: True})
 
 
@@ -62,7 +66,7 @@ def fpath(tmpdir):
 def favicon_data():
     return base64.b64decode(
         "iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAADUlEQVQ"
-        + "ImWO4ISn6HwAE2QIGKsd69QAAAABJRU5ErkJggg=="
+        "ImWO4ISn6HwAE2QIGKsd69QAAAABJRU5ErkJggg=="
     )
 
 
@@ -127,13 +131,13 @@ def lipsum_item(lipsum):
 
 
 def test_imports():
-    assert libzim.writer.Compression  # noqa
-    assert libzim.writer.Blob  # noqa
-    assert libzim.writer.Item  # noqa
-    assert libzim.writer.ContentProvider  # noqa
-    assert libzim.writer.FileProvider  # noqa
-    assert libzim.writer.StringProvider  # noqa
-    assert libzim.writer.Creator  # noqa
+    assert libzim.writer.Compression
+    assert libzim.writer.Blob
+    assert libzim.writer.Item
+    assert libzim.writer.ContentProvider
+    assert libzim.writer.FileProvider
+    assert libzim.writer.StringProvider
+    assert libzim.writer.Creator
 
 
 def test_creator_filename(fpath):
@@ -151,7 +155,7 @@ def get_creator_output(fpath, verbose):
     """run creator with configVerbose(verbose) and return its stdout as str"""
     code = """
 from libzim.writer import Creator
-with Creator("{fpath}").config_verbose({verbose}) as creator:
+with Creator(r"{fpath}").config_verbose({verbose}) as creator:
     pass
 """.replace(
         "{fpath}", str(fpath)
@@ -162,13 +166,14 @@ with Creator("{fpath}").config_verbose({verbose}) as creator:
         [sys.executable, "-c", code],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
-        universal_newlines=True,
+        text=True,
+        check=False,
     )
     assert ps.returncode == 0
     return ps.stdout
 
 
-@pytest.mark.parametrize("verbose", [(True, False)])
+@pytest.mark.parametrize("verbose", [True, False])
 def test_creator_verbose(fpath, verbose):
     output = get_creator_output(fpath, verbose).strip()
     lines = output.splitlines()
@@ -249,9 +254,14 @@ def test_creator_nbworkers(fpath, lipsum_item, nb_workers):
 
 
 def test_creator_combine_config(fpath, lipsum_item):
-    with Creator(fpath).config_verbose(True).config_compression(
-        "zstd"
-    ).config_clustersize(1024).config_indexing(True, "eng").config_nbworkers(2) as c:
+    with (
+        Creator(fpath)
+        .config_verbose(True)
+        .config_compression("zstd")
+        .config_clustersize(1024)
+        .config_indexing(True, "eng")
+        .config_nbworkers(2) as c
+    ):
         c.add_item(lipsum_item)
 
 
@@ -288,7 +298,7 @@ def test_creator_nocontext(fpath, lipsum_item):
     creator.__enter__()
     creator.add_item(lipsum_item)
     try:
-        creator.add_redirection("A", HOME_PATH)
+        creator.add_redirection("A", HOME_PATH)  # pyright: ignore [reportCallIssue]
     except Exception:
         exc_type, exc_val, exc_tb = sys.exc_info()
         with pytest.raises(TypeError):
@@ -323,6 +333,7 @@ def test_creator_mainpath(fpath, lipsum_item):
     assert zim.has_main_entry is True
     assert zim.main_entry.path == "mainPage"
     assert zim.main_entry.get_item().path == main_path
+    del zim
 
     fpath.unlink()
 
@@ -359,11 +370,11 @@ def test_creator_additem(fpath, lipsum_item):
     with Creator(fpath) as c:
         c.add_item(lipsum_item)
         with pytest.raises(TypeError, match="must not be None"):
-            c.add_item(None)
+            c.add_item(None)  # pyright: ignore [reportCallIssue, reportArgumentType]
         with pytest.raises(RuntimeError):
-            c.add_item("hello")
-        with pytest.raises(TypeError, match="takes no keyword arguments"):
-            c.add_item(mimetype="text/html")
+            c.add_item("hello")  # pyright: ignore [reportCallIssue, reportArgumentType]
+        with pytest.raises(TypeError, match="takes exactly 1 positional argument"):
+            c.add_item(mimetype="text/html")  # pyright: ignore [reportCallIssue]
 
 
 def test_creator_metadata(fpath, lipsum_item):
@@ -394,7 +405,7 @@ def test_creator_metadata(fpath, lipsum_item):
     c = Creator(fpath)
     with pytest.raises(RuntimeError, match="not started"):
         key = next(iter(metadata.keys()))
-        c.add_metadata(key, metadata.get(key))
+        c.add_metadata(key, metadata[key])
     del c
 
     with Creator(fpath) as c:
@@ -404,7 +415,7 @@ def test_creator_metadata(fpath, lipsum_item):
                 continue
             c.add_metadata(name, value)
 
-        mdate = datetime.date(*[int(x) for x in metadata.get("Date").split("-")])
+        mdate = datetime.date(*[int(x) for x in metadata.get("Date", "").split("-")])
         c.add_metadata("Date", mdate)
 
     zim = Archive(fpath)
@@ -468,6 +479,35 @@ def test_creator_redirection(fpath, lipsum_item):
     )
 
 
+def test_creator_alias(fpath, lipsum_item):
+    # ensure we can't add if not started
+    c = Creator(fpath)
+    with pytest.raises(RuntimeError, match="not started"):
+        c.add_redirection("home", "hello", HOME_PATH, {Hint.FRONT_ARTICLE: True})
+    del c
+
+    with Creator(fpath) as c:
+        c.add_item(lipsum_item)
+        c.add_alias("home", "hello", HOME_PATH, {Hint.FRONT_ARTICLE: True})
+        with pytest.raises(RuntimeError, match="doesn't exist"):
+            c.add_alias(
+                "accueil",
+                "bonjour",
+                HOME_PATH + "_non_existent",
+                {Hint.FRONT_ARTICLE: True},
+            )
+
+    zim = Archive(fpath)
+    assert zim.entry_count == 2
+    assert zim.has_entry_by_path("home") is True
+    assert zim.has_entry_by_path("accueil") is False
+    assert not zim.get_entry_by_path("home").is_redirect
+    assert (
+        zim.get_entry_by_path("home").get_item().content
+        == zim.get_entry_by_path(HOME_PATH).get_item().content
+    )
+
+
 def test_item_notimplemented(fpath, lipsum_item):
     item = Item()
 
@@ -551,7 +591,7 @@ def test_item_contentprovider_none(fpath):
 
     with Creator(fpath) as c:
         with pytest.raises(RuntimeError, match="ContentProvider is None"):
-            c.add_item(AnItem())
+            c.add_item(AnItem())  # pyright: ignore [reportArgumentType]
 
 
 def test_missing_contentprovider(fpath):
@@ -570,7 +610,7 @@ def test_missing_contentprovider(fpath):
 
     with Creator(fpath) as c:
         with pytest.raises(RuntimeError, match="has no attribute"):
-            c.add_item(AnItem())
+            c.add_item(AnItem())  # pyright: ignore [reportArgumentType]
 
 
 def test_missing_hints(fpath):
@@ -586,7 +626,7 @@ def test_missing_hints(fpath):
 
     with Creator(fpath) as c:
         with pytest.raises(RuntimeError, match="has no attribute 'get_hints'"):
-            c.add_item(AnItem())
+            c.add_item(AnItem())  # pyright: ignore [reportArgumentType]
 
         with pytest.raises(RuntimeError, match="must be implemented"):
             c.add_item(libzim.writer.Item())
@@ -598,7 +638,9 @@ def test_nondict_hints(fpath):
             c.add_item(StaticItem(path="1", title="", hints=1))
 
         with pytest.raises(TypeError, match="hints"):
-            c.add_redirection("a", "", "b", hints=1)
+            c.add_redirection(
+                "a", "", "b", hints=1  # pyright: ignore [reportArgumentType]
+            )
 
 
 def test_hints_values(fpath):
@@ -627,11 +669,22 @@ def test_hints_values(fpath):
 
         # non-existent Hint
         with pytest.raises(AttributeError, match="YOLO"):
-            c.add_item(StaticItem(path="0", title="", hints={Hint.YOLO: True}))
+            c.add_item(
+                StaticItem(
+                    path="0",
+                    title="",
+                    hints={
+                        Hint.YOLO: True  # pyright: ignore [reportAttributeAccessIssue]
+                    },
+                )
+            )
 
         with pytest.raises(AttributeError, match="YOLO"):
-            c.add_redirection(
-                path="5", title="", target_path="0", hints={Hint.YOLO: True}
+            c.add_redirection(  # pyright: ignore [reportCallIssue]
+                path="5",
+                title="",
+                targetPath="0",
+                hints={Hint.YOLO: True},  # pyright: ignore [reportAttributeAccessIssue]
             )
 
 
@@ -720,7 +773,7 @@ def test_reimpfeed(fpath):
             self.called = True
             return Blob("1")
 
-    class AnItem:
+    class AnItem(Item):
         def get_path(self):
             return "-"
 
@@ -753,7 +806,7 @@ def test_virtualmethods_int_exc(fpath):
         def feed(self):
             return Blob("")
 
-    class AnItem:
+    class AnItem(Item):
         def get_path(self):
             return ""
 
@@ -775,11 +828,54 @@ def test_virtualmethods_int_exc(fpath):
 
 
 def test_creator_badfilename(tmpdir):
-    if os.getuid() != 0:
+    if platform.system() != "Windows" and os.getuid() != 0:
         # lack of perm
         with pytest.raises(IOError):
-            Creator("/root/test.zim")
+            Creator(pathlib.Path("/root/test.zim"))
 
     # forward slash points to non-existing folder
     with pytest.raises(IOError):
         Creator(tmpdir / "test/test.zim")
+
+
+def test_accented_search_from_libzim(fpath):
+    """copy of libzim accented search test
+
+    https://github.com/openzim/libzim/blob/main/test/search.cpp#L290 (88543b00)"""
+
+    with Creator(fpath).config_verbose(True).config_indexing(True, "eng") as creator:
+        creator.add_item(
+            StaticItem(
+                path="path0",
+                title="Test Article0",
+                content="This is a tèst articlé. temp0",
+                mimetype="text/html",
+            )
+        )
+
+        creator.add_item(
+            StaticItem(
+                path="path1",
+                title="Test Article1",
+                content="This is another test article. For article1.",
+                mimetype="text/html",
+            )
+        )
+
+    zim = Archive(fpath)
+
+    assert zim.entry_count == 2
+    assert zim.article_count == 2
+    assert zim.all_entry_count == 7
+
+    ascii_query = Query().set_query("test article")
+    ascii_searcher = Searcher(zim)
+    ascii_search = ascii_searcher.search(ascii_query)
+    assert ascii_search.getEstimatedMatches() == zim.article_count
+    assert list(ascii_search.getResults(0, zim.article_count)) == ["path0", "path1"]
+
+    accented_query = Query().set_query("test àrticlé")
+    accented_searcher = Searcher(zim)
+    accented_search = accented_searcher.search(accented_query)
+    assert accented_search.getEstimatedMatches() == zim.article_count
+    assert list(accented_search.getResults(0, zim.article_count)) == ["path0", "path1"]
